'''Determines message types and priorities'''

__licence__ = "GPLv2"
__copyright__ = "2007, Lauri Taimila"
__author__ = "Lauri Taimila <lauri@taimila.com>"

class MessagePriority:
    """
    Simply determines Message priority constants.

    These are used when MessageHandlers are registered to the MessageBus.
    This definition makes code easy to read.
    """
    VERY_HIGH = 0
    HIGH = 10
    NORMAL = 20
    LOW = 30
    VERY_LOW = 40

class MessageType:
    """
    Determines all allowed Message types. MessageHandler should use these
    to determine type. This simply makes code more readable.

    Example:
        if message.get_type() == MessageType.FRONTEND_OPENED:
            do_something_useful()
    """

    # Indicates that Preferences UI has been used to update preferences.
    PREFERENCES_CONF_UPDATED = 0

    # Indicates that Content Management UI has been used to update contents.
    CONTENT_CONF_UPDATED = 1

    # Indicates that frontend has been opened.
    FRONTEND_OPENED = 2

    # Indicates that frontend has been closed.
    FRONTEND_CLOSED = 3

    # Indicates that Feed cache has been updated.
    FEED_DB_UPDATED = 4

    NOT_USED_5 = 5

    NOT_USED_1 = 6

    # Indicates that Feed cache should be updated.
    UPDATE_FEEDS = 7

    NOT_USED_6 = 8

    #This should be left in otherwise message_bus.py breaks
    #If another message type is needed please use this
    DO_NOT_DELETE_USE_NEXT = 9

    NOT_USED_2 = 10
    NOT_USED_3 = 11
    NOT_USED_4 = 12

    # Require to rebuild image cache
    REBUILD_IMAGE_CACHE = 13

    # Require to rebuild music cache
    REBUILD_MUSIC_CACHE = 14

    # Require to rebuild video cache
    REBUILD_VIDEO_CACHE = 15

    # Require to rebuild feed cache
    REBUILD_FEED_CACHE = 16

