'''Connection to the Entertainer backend'''

__licence__ = "GPLv2"
__copyright__ = "2007, Lauri Taimila"
__author__ = "Lauri Taimila <lauri@taimila.com>"

from entertainerlib.backend.core.message import Message
from entertainerlib.backend.core.message_bus_proxy import MessageBusProxy
from entertainerlib.backend.core.message_type_priority import MessageType
from entertainerlib.backend.core.message_handler import MessageHandler

class BackendConnection(MessageHandler):
    """
    BackendConnection - Connection to the Entertainer backend. Instance from
    this class is a gate to backend messagebus.
    """

    def __init__(self):
        """Initialize connection. Connects to backend."""
        #messages = {
        #    MessageType.CONTENT_CONF_UPDATED : MessagePriority.NORMAL,
        #    MessageType.PREFERENCES_CONF_UPDATED : MessagePriority.NORMAL,
        #    MessageType.FEED_DB_UPDATED : MessagePriority.HIGH }
        # XXX: rockstar - The messages above are the "real" messages, and I'm
        # not sure why they are commented out.  Anyone?
        MessageHandler.__init__(self)
        messages = {}
        name = "Entertainer Frontend"
        self.message_bus_proxy = MessageBusProxy(messages, self, name)
        self.message_bus_proxy.connectToMessageBus()
        self.message_bus_proxy.start()
        self.message_bus_proxy.sendMessage(
            Message(MessageType.FRONTEND_OPENED))

    def close_connection(self):
        """Close connection to backend"""
        self.message_bus_proxy.sendMessage(
            Message(MessageType.FRONTEND_CLOSED))
        self.message_bus_proxy.disconnectFromMessageBus()

    def request_feed_update(self):
        """Request backend to fetch all feeds from the Internet."""
        self.message_bus_proxy.sendMessage(Message(MessageType.UPDATE_FEEDS))

    def request_weather_update(self):
        """Request backend to update weather information from the Internet."""
        self.message_bus_proxy.sendMessage(Message(MessageType.UPDATE_WEATHER))

    # Implements MessageHandler interface
    def handleMessage(self, message):
        """Handle received messages. (Implements MessageHandler interface)"""
        if message.get_type() == MessageType.CONTENT_CONF_UPDATED:
            pass
        elif message.get_type() == MessageType.PREFERENCES_CONF_UPDATED:
            pass
        elif message.get_type() == MessageType.FEED_DB_UPDATED:
            pass

