'''Artist - Screen allows user to browse music of one specific artist'''

__licence__ = "GPLv2"
__copyright__ = "2007, Lauri Taimila"
__author__ = "Lauri Taimila <lauri@taimila.com>"

import pango

from entertainerlib.frontend.gui.screens.screen import Screen
from entertainerlib.frontend.gui.tabs.albums_tab import AlbumsTab
from entertainerlib.frontend.gui.tabs.tracks_tab import TracksTab
from entertainerlib.frontend.gui.widgets.label import Label
from entertainerlib.frontend.medialibrary.playlist import Playlist

class Artist(Screen):
    '''Artist - Screen that allows user to browse music by artist.'''

    def __init__(self, media_player, music_library, artist,
        move_to_new_screen_callback):

        Screen.__init__(self, move_to_new_screen_callback, has_tabs=True)

        self.media_player = media_player

        # Screen Title (Displayed at the bottom left corner)
        screen_title = Label(0.13, "screentitle", 0, 0.87, artist)
        screen_title.set_ellipsize(pango.ELLIPSIZE_END)
        screen_title.width = 1
        self.add(screen_title)

        # Tabs
        albums = music_library.get_albums_by_artist(artist)
        tab1 = AlbumsTab(albums, move_to_new_screen_callback)

        tracks = music_library.get_tracks_by_artist(artist)
        tab2 = TracksTab(tracks, move_to_new_screen_callback)
        tab2.hide_tab()

        self.add_tab(tab1)
        self.add_tab(tab2)

    def is_interested_in_play_action(self):
        """
        Override function from Screen class. See Screen class for
        better documentation.
        """
        if self.tab_group.tab("albums").is_active():
            return True
        else:
            return False

    def execute_play_action(self):
        """
        Override function from Screen class. See Screen class for
        better documentation.
        """
        album = self.tab_group.tab("albums").selected_album
        self.media_player.set_playlist(Playlist(album.get_tracks()))
        self.media_player.play()

    def get_type(self):
        """Return screen type."""
        return Screen.NORMAL

    def get_name(self):
        """Return screen name (human readble)"""
        return "ArtistScreen"

