'''AudioPlay - Screen displays information of currently playing audio'''
# pylint: disable-msg=W0221

__licence__ = "GPLv2"
__copyright__ = "2007, Lauri Taimila"
__author__ = "Lauri Taimila <lauri@taimila.com>"

import gtk
import gobject
import clutter

from entertainerlib.frontend.gui.screens.screen import Screen
from entertainerlib.frontend.gui.tabs.lyrics_tab import LyricsTab
from entertainerlib.frontend.gui.tabs.playing_tab import PlayingTab
from entertainerlib.frontend.gui.tabs.playlist_tab import PlaylistTab
from entertainerlib.frontend.gui.widgets.eyecandy_texture import (
    EyeCandyTexture)

class AudioPlay(Screen):
    """
    AudioPlay

    Screen that displays information of currently playing audio track.
    """

    def __init__(self, media_player, music_library, track):

        Screen.__init__(self, has_tabs=True)

        self.theme = self.config.theme
        album = track.get_album()

        # Create album art (this is displayed on all tab pages
        if(album.has_album_art()):
            pixbuf = gtk.gdk.pixbuf_new_from_file(album.get_album_art_url())
        else:
            pixbuf = gtk.gdk.pixbuf_new_from_file(
                self.theme.getImage("default_album_art"))
        self.art = EyeCandyTexture(pixbuf, self.get_abs_x(0.3148),
            self.get_abs_y(0.5599))
        self.art.set_position(self.get_abs_x(0.1), self.get_abs_y(0.22))
        self.art.set_rotation(clutter.Y_AXIS, 25, 0, 0, 0)
        self.add(self.art)

        # Tabs
        tab1 = PlayingTab(track)
        tab2 = LyricsTab(music_library, track)
        tab3 = PlaylistTab()
        self.add_tab(tab1)
        self.add_tab(tab2)
        self.add_tab(tab3)

        media_player.set_media(track)
        media_player.play()

        # Start updating the progress bar of the PlayingTab (1/4 sec)
        gobject.timeout_add(250, tab1.update_progress_bar, media_player)

    def update(self, track):
        '''Called when currently playing changes tracks. The provided track
        is used to update all the necessary labels'''
        self.tab_group.tab("playing").update(track)

    def get_type(self):
        """Return screen type."""
        return Screen.NORMAL

    def get_name(self):
        """Return screen name (human readble)"""
        return "AudioPlay"

