'''Question - Screen displays a question label and specified buttons.'''

__licence__ = "GPLv2"
__copyright__ = "2008, Teje Rodgers"
__author__ = "Teje Rodgers <contact@tejerodgers.com>"

from entertainerlib.frontend.gui.screens.screen import Screen
from entertainerlib.frontend.gui.transitions.transition import Transition
from entertainerlib.frontend.gui.widgets.label import Label
from entertainerlib.frontend.gui.widgets.text_menu import TextMenu
from entertainerlib.frontend.gui.widgets.text_menu_item import TextMenuItem

class Question(Screen):
    '''
    Question screen

    This is displayed when the application needs to ask a close ended question
    to the user.
    '''
    def __init__(self, screen_history, change_screen_callback, question,
        answers, callbacks=None):
        Screen.__init__(self)

        self.theme = self.config.theme

        self.screen_history = screen_history
        self.change_screen_callback = change_screen_callback
        self.answers = answers

        if callbacks is None:
            callbacks = []
        self.callbacks = callbacks

        screen_title = Label(0.13, "screentitle", 0, 0.87, _("Question"))
        self.add(screen_title)

        question_label = Label(0.04167, "text", 0.095, 0.13, str(question))
        self.add(question_label)

        self.menu = None
        self.display_answers()

    def display_answers(self):
        '''Display a menu with answers on the screen.'''
        self.menu = TextMenu(self.theme, self.config.show_effects())
        self.menu.set_name("questionmenu")
        self.menu.set_row_count(1)
        self.menu.set_visible_column_count(7)
        self.menu.set_item_size(self.get_abs_x(0.4393), self.get_abs_y(0.0781))
        self.menu.set_position(self.get_abs_x(0.095), self.get_abs_y(0.5))

        for answer in self.answers:
            item = TextMenuItem(0.4173, 0.0781, str(answer))
            item.set_userdata(str(answer))
            self.menu.add_actor(item)

        self.add(self.menu)

    def question_callback(self, selected_answer):
        '''Call the method associated with the selected answer.'''
        callback_loc = 0
        for answer in self.answers:
            if str(answer) == selected_answer:
                break
            callback_loc += 1

        if callback_loc < len(self.callbacks):
            callback = self.callbacks[callback_loc]
            if callback != None:
                callback()

    def get_type(self):
        '''Return screen type.'''
        return Screen.NORMAL

    def get_name(self):
        '''Return object name, to comply with clutter'''
        return str(self)

    def __str__(self):
        '''Return screen name (human readble)'''
        return "Question"

    def go_back(self):
        '''Go back to previous screen'''
        screen = self.screen_history.get_screen()
        screen.update()
        self.change_screen_callback(screen, Transition.BACKWARD)

    def _move_menu(self, menu_direction):
        '''Move the menu in the given direction.'''
        self.menu.move(menu_direction)

    def _handle_up(self):
        '''Handle UserEvent.NAVIGATE_UP.'''
        self._move_menu(TextMenu.UP)

    def _handle_down(self):
        '''Handle UserEvent.NAVIGATE_DOWN.'''
        self._move_menu(TextMenu.DOWN)

    def _handle_select(self):
        '''Handle UserEvent.NAVIGATE_SELECT.'''
        self.question_callback(self.menu.get_current_menuitem().get_userdata())
        self.go_back()

