'''TvSeries - Screen allows user to browse seasons of one TV series'''

__licence__ = "GPLv2"
__copyright__ = "2007, Lauri Taimila"
__author__ = "Lauri Taimila <lauri@taimila.com>"

import gtk

from entertainerlib.frontend.gui.screens.screen import Screen
from entertainerlib.frontend.gui.widgets.eyecandy_texture import (
    EyeCandyTexture)
from entertainerlib.frontend.gui.widgets.label import Label
from entertainerlib.frontend.gui.widgets.list_indicator import ListIndicator
from entertainerlib.frontend.gui.widgets.text_menu import TextMenu
from entertainerlib.frontend.gui.widgets.text_menu_item import TextMenuItem

class TvSeries(Screen):
    """
    TvSeries

    This screen contains all seasons of one TV series.
    """

    def __init__(self, move_to_new_screen_callback, tv_series):
        Screen.__init__(self, move_to_new_screen_callback)

        self.theme = self.config.theme
        self.tv_series = tv_series

        # Screen Title (Displayed at the bottom left corner)
        screen_title = Label(0.13, "screentitle", 0, 0.87,
            self.tv_series.get_title())
        self.add(screen_title)

        self.art = None
        self.season_menu = None
        self._create_series_cover_texture()
        self._create_season_menu()

        #List indicator
        self.li = ListIndicator(0.2, 0.045, ListIndicator.VERTICAL)
        self.li.set_position(self.config.get_stage_width() -
            self.li.get_width() - self.get_abs_x(0.0659),
            self.config.get_stage_height() - self.get_abs_y(0.1953))
        self.li.set_delimiter(" | ")
        self.li.set_maximum(self.season_menu.get_number_of_items())
        self.li.set_current(1)
        self.add(self.li)

    def _create_season_menu(self):
        """
        Create a list of available seasons
        """
        self.season_menu = TextMenu(self.theme, self.config.show_effects())
        self.season_menu.set_row_count(1)
        self.season_menu.set_item_size(self.get_abs_x(0.4393),
            self.get_abs_y(0.0781))
        self.season_menu.set_position(self.get_abs_x(0.4978),
            self.get_abs_y(0.1563))

        # Create menu items based on MusicLibrary
        seasons = self.tv_series.get_seasons()
        seasons.sort()
        for season in seasons:
            item = TextMenuItem(0.4393, 0.0781,
                _("Season %(num)s") % {'num': season})
            item.set_userdata(season)
            self.season_menu.add_actor(item)

        self.season_menu.set_active(True)
        self.add(self.season_menu)

    def _create_series_cover_texture(self):
        """
        Create a texture that is displayed next to track list. This texture
        displays album cover art.
        """
        if(self.tv_series.has_cover_art()):
            pixbuf = gtk.gdk.pixbuf_new_from_file(
                self.tv_series.get_cover_art_url())
        else:
            pixbuf = gtk.gdk.pixbuf_new_from_file(
                self.theme.getImage("default_movie_art"))
        self.art = EyeCandyTexture(pixbuf, self.get_abs_x(0.2196),
            self.get_abs_y(0.5859))
        self.art.set_position(self.get_abs_x(0.16), self.get_abs_y(0.15))
        self.add(self.art)

    def get_type(self):
        """Return screen type."""
        return Screen.NORMAL

    def get_name(self):
        """Return screen name (human readble)"""
        return "TvSeries"

    def _move_menu(self, menu_direction):
        '''Move the menu in the given direction.'''
        self.season_menu.move(menu_direction)
        self.li.set_current(self.season_menu.get_current_position() + 1)

    def _handle_up(self):
        '''Handle UserEvent.NAVIGATE_UP.'''
        self._move_menu(TextMenu.UP)

    def _handle_down(self):
        '''Handle UserEvent.NAVIGATE_DOWN.'''
        self._move_menu(TextMenu.DOWN)

    def _handle_select(self):
        '''Handle UserEvent.NAVIGATE_SELECT.'''
        season = self.season_menu.get_current_menuitem().get_userdata()
        kwargs = { 'tv_series' : self.tv_series, 'season_number' : season }
        self.callback("tv_episodes", kwargs)

