'''Video - Screen allows user to browse video library content'''

__licence__ = "GPLv2"
__copyright__ = "2008, Lauri Taimila"
__author__ = "Lauri Taimila <lauri@taimila.com>"

from entertainerlib.frontend.gui.screens.screen import Screen
from entertainerlib.frontend.gui.tabs.movies_tab import MoviesTab
from entertainerlib.frontend.gui.tabs.series_tab import SeriesTab
from entertainerlib.frontend.gui.tabs.video_clips_tab import VideoClipsTab
from entertainerlib.frontend.gui.widgets.label import Label

class Video(Screen):
    """
    Video

    This screen contains tabs for different video types. This is the top level
    UI for video library.
    """

    def __init__(self, media_player, video_library,
        move_to_new_screen_callback):
        Screen.__init__(self, has_tabs=True)

        # Screen Title (Displayed at the bottom left corner)
        screen_title = Label(0.13, "screentitle", 0, 0.87, _("Videos"))
        self.add(screen_title)

        # Tabs
        tab1 = MoviesTab(video_library, move_to_new_screen_callback)
        tab2 = SeriesTab(video_library, move_to_new_screen_callback)
        tab3 = VideoClipsTab(media_player, video_library,
            move_to_new_screen_callback)

        self.add_tab(tab1)
        self.add_tab(tab2)
        self.add_tab(tab3)

    def get_type(self):
        """
        Get screen type.
        @return: Integer (Constant variable from Screen class)
        """
        return Screen.NORMAL

    def get_name(self):
        """
        Get screen name (human readable)
        @return: String
        """
        return "Video"

