'''WeatherScreen - Screen allows user to view current weather conditions'''

__licence__ = "GPLv2"
__copyright__ = "2008, Jamie Bennett"
__author__ = "Jamie Bennett <jamie@linuxuk.org>"

from entertainerlib.frontend.gui.screens.screen import Screen
from entertainerlib.frontend.gui.widgets.label import Label
from entertainerlib.frontend.gui.widgets.texture import Texture
from entertainerlib.utils.weather import Weather

class WeatherScreen(Screen):
    """
    WeatherScreen

    Front end weather forecast screen
    """

    def __init__(self):
        Screen.__init__(self)

        loc = self.config.get_weather_location()
        self.weather = Weather(loc)
        self.weather.refresh()

        # Screen Title (Displayed at the bottom left corner)
        screen_title = Label(0.13, "screentitle", 0, 0.87, _("Weather"))
        self.add(screen_title)

        # Show the location
        if (self.weather.get_location() == ''):
            location_text = _("No weather location defined!")
        else:
            location_text = self.weather.get_location()

        location = Label(0.04167, "text", 0.40, 0.13, location_text,
            font_weight="bold")
        self.add(location)

        forecasts = self.weather.get_forecasts()

        # Show today's weather
        day = forecasts[0]

        weather_image = Texture(day["Image"], 0.1, 0.15)
        self.add(weather_image)

        day1 = Label(0.04167, "text", 0.13, 0.35, day["Day"],
            font_weight="bold")
        self.add(day1)

        day1_more_text = \
            _("High: %(high)s   Low: %(low)s\nCondition: %(cond)s") % \
            {'high': day["High"], 'low': day["Low"], 'cond': day["Condition"]}
        day1_more = Label(0.03, "text", 0.13, 0.40, day1_more_text)
        self.add(day1_more)

        # Show tomorrow's weather
        day = forecasts[1]

        weather_image = Texture(day["Image"], 0.1, 0.5)
        self.add(weather_image)

        day2 = Label(0.04167, "text", 0.13, 0.7, day["Day"], font_weight="bold")
        self.add(day2)

        day2_more_text = \
            _("High: %(high)s   Low: %(low)s\nCondition: %(cond)s") % \
            {'high': day["High"], 'low': day["Low"], 'cond': day["Condition"]}
        day2_more = Label(0.03, "text", 0.13, 0.75, day2_more_text)
        self.add(day2_more)

        # Show day 3
        day = forecasts[2]

        weather_image = Texture(day["Image"], 0.4, 0.5)
        self.add(weather_image)

        day3 = Label(0.04167, "text", 0.4, 0.7, day["Day"], font_weight="bold")
        self.add(day3)

        day3_more_text = \
            _("High: %(high)s   Low: %(low)s\nCondition: %(cond)s") % \
            {'high': day["High"], 'low': day["Low"], 'cond': day["Condition"]}
        day3_more = Label(0.03, "text", 0.4, 0.75, day3_more_text)
        self.add(day3_more)

        # Show day 4
        day = forecasts[3]

        weather_image = Texture(day["Image"], 0.7, 0.5)
        self.add(weather_image)

        day4 = Label(0.04167, "text", 0.7, 0.7, day["Day"], font_weight="bold")
        self.add(day4)

        day4_more_text = \
            _("High: %(high)s   Low: %(low)s\nCondition: %(cond)s") % \
            {'high': day["High"], 'low': day["Low"], 'cond': day["Condition"]}
        day4_more = Label(0.03, "text", 0.7, 0.75, day4_more_text)
        self.add(day4_more)

    def get_type(self):
        """Return screen type."""
        return Screen.NORMAL

    def get_name(self):
        """Return screen name (human readble)"""
        return "WeatherScreen"

