'''Lyrics tab for the audio play screen'''

__licence__ = "GPLv2"
__copyright__ = "2008, Matt Layman"
__author__ = "Matt Layman <laymansterms.dev@gmail.com>"

import pango
import clutter

from entertainerlib.frontend.gui.tabs.tab import Tab
from entertainerlib.frontend.gui.widgets.label import Label
from entertainerlib.frontend.gui.widgets.loading_animation import (
    LoadingAnimation)
from entertainerlib.frontend.gui.widgets.scroll_area import ScrollArea

class LyricsTab(Tab):
    '''Tab for the audio play screen to show lyrics'''

    def __init__(self, music_library, track, name="lyrics",
        tab_title=_("Lyrics")):
        Tab.__init__(self, name, tab_title)
        self.track = track
        self.lyrics_area = None
        self.library = music_library
        self.lyrics_text = None

        if self.track.has_lyrics():
            lyrics = Label(0.037, "subtitle", 0, 0, self.track.get_lyrics())
            lyrics.set_line_wrap_mode(pango.WRAP_WORD)
            lyrics.width = 0.366

            self.lyrics_area = ScrollArea(0.4, 0.57, 0.5, 0.23, lyrics)
            self.add(self.lyrics_area)
        else:
            # Display throbber animation while searching for lyrics
            white = clutter.Color(255, 255, 255, 255)
            gray = clutter.Color(128, 128, 128, 128)
            self.throbber = LoadingAnimation(50, white, gray)
            self.throbber.set_position(self.get_abs_x(0.7), self.get_abs_y(0.5))
            self.throbber.show()
            self.add(self.throbber)
            self.track.fetch_lyrics(self._lyrics_search_callback)

        self.hide_tab()

    def _lyrics_search_callback(self, lyrics_text):
        """
        This function is called when lyrics search is over.
        @param lyrics: Lyrics or None if lyrics weren't found
        """
        #TODO: We could smoothly fade away throbber
        self.throbber.hide()

        # Save the results to help determine if the tab can activate
        self.lyrics_text = lyrics_text

        if lyrics_text is None:
            no_lyrics = Label(0.037, "title", 0.5, 0.5,
                _("No lyrics found for this track"))
            self.add(no_lyrics)
        else:
            lyrics = Label(0.037, "subtitle", 0, 0, lyrics_text)
            lyrics.set_line_wrap_mode(pango.WRAP_WORD)
            lyrics.width = 0.366

            self.lyrics_area = ScrollArea(0.4, 0.57, 0.5, 0.23, lyrics)
            self.add(self.lyrics_area)
            self.library.save_lyrics(self.track, lyrics_text)

    def can_activate(self):
        '''Lyrics tab can scroll the lyrics listing only if lyrics were found'''
        if self.lyrics_text is None:
            return False
        else:
            return True

    def set_active(self, boolean):
        """
        Override method from parent class.
        @param boolean: True to set this tab active, False to set inactive
        """
        Tab.set_active(self, boolean)
        if boolean:
            self.lyrics_area.set_active(True)
        else:
            self.lyrics_area.set_active(False)

    def _handle_up(self):
        '''Handle the up user event'''
        if self.lyrics_area.get_offset() == 0:
            return True # Move control back to tab bar
        else:
            return self.lyrics_area.scroll_up()

    def _handle_down(self):
        '''Handle the down user event'''
        return self.lyrics_area.scroll_down()

