'''Currently playing tab for the audio screen'''

__licence__ = "GPLv2"
__copyright__ = "2008, Matt Layman"
__author__ = "Matt Layman <laymansterms.dev@gmail.com>"

import pango

from entertainerlib.frontend.gui.tabs.tab import Tab
from entertainerlib.frontend.gui.widgets.label import Label
from entertainerlib.frontend.gui.widgets.progress_bar import ProgressBar

class PlayingTab(Tab):
    '''Tab for the audio play screen to show currently playing audio'''

    def __init__(self, track, name="playing", tab_title=_("Currently playing")):
        Tab.__init__(self, name, tab_title)
        album = track.get_album()

        # Track name
        if track.get_tracknumber() == 0:
            track_label_text = str(track.get_title())
        else:
            track_label_text = str(track.get_tracknumber()) + \
                ". " + track.get_title()

        self.track_label = Label(0.05, "text", 0.5, 0.33, track_label_text)
        self.track_label.set_ellipsize(pango.ELLIPSIZE_END)
        self.track_label.width = 0.4
        self.add(self.track_label)

        # Album name
        if album.get_year() != 0:
            album_label_text = _("From %(title)s, %(year)s") % \
            {'title': album.get_title(), 'year': album.get_year()}
        else:
            album_label_text = _("From ") + album.get_title()

        self.album_label = Label(0.042, "subtitle", 0.5, 0.43, album_label_text)
        self.album_label.set_ellipsize(pango.ELLIPSIZE_END)
        self.album_label.width = 0.4
        self.add(self.album_label)

        # Artist name
        artist_text = _("By %(artist)s") % {'artist': track.get_artist()}
        self.artist_label = Label(0.042, "subtitle", 0.5, 0.53, artist_text)
        self.artist_label.set_ellipsize(pango.ELLIPSIZE_END)
        self.artist_label.width = 0.4
        self.add(self.artist_label)

        # Current position as time stamp
        self.current_pos = Label(0.037, "title", 0.5, 0.665, "00:00")
        self.add(self.current_pos)

        self.progress_bar = ProgressBar(self.get_abs_x(0.3001),
            self.get_abs_y(0.03906), self.config.theme.get_color("title"))
        self.progress_bar.set_position(self.get_abs_x(0.565),
            self.get_abs_y(0.667))
        self.add(self.progress_bar)

        self.track_length = Label(0.037, "title", 0.871, 0.665,
            track.get_length_string())
        self.add(self.track_length)

    def update_progress_bar(self, player):
        '''Update the progress bar'''
        self.progress_bar.set_progress(player.get_media_position())
        self.current_pos.set_text(player.get_media_position_string())
        return True

    def update(self, track):
        '''Called when currently playing changes tracks. The provided track
        is used to update all the necessary labels'''
        track = track
        album = track.get_album()

        if track.get_tracknumber() == 0:
            self.track_label.set_text(str(track.get_title()))
        else:
            self.track_label.set_text(str(track.get_tracknumber()) + \
                ". " + track.get_title())

        if album.get_year() != 0:
            self.album_label.set_text(_("From %(title)s, %(year)s") % \
            {'title': album.get_title(), 'year': album.get_year()})
        else:
            self.album_label.set_text(_("From %(album)s") % \
                {'album': album.get_title()})
            self.artist_label.set_text(_("By %(artist)s") % \
                {'artist': track.get_artist()})

        self.current_pos.set_text("00:00")
        self.track_length.set_text(track.get_length_string())
        self.progress_bar.set_progress(0)

    def can_activate(self):
        '''No interaction is available on the PlayingTab'''
        return False

