'''Playlists tab for the music screen'''

__licence__ = "GPLv2"
__copyright__ = "2008, Matt Layman"
__author__ = "Matt Layman <laymansterms.dev@gmail.com>"

import clutter

from entertainerlib.frontend.gui.tabs.tab import Tab
from entertainerlib.frontend.gui.widgets.label import Label
from entertainerlib.frontend.gui.widgets.text_menu import TextMenu
from entertainerlib.frontend.gui.widgets.text_menu_item import TextMenuItem

class PlaylistsTab(Tab):
    '''Tab for the music screen to show playlists.'''

    def __init__(self, playlists, name="playlists", tab_title=_("Playlists")):
        Tab.__init__(self, name, tab_title)
        if len(playlists) == 0:
            empty_label = Label(0.05, "title", 0.5, 0.5,
                _("No saved playlists available."))
            empty_label.set_anchor_point_from_gravity(clutter.GRAVITY_CENTER)
            self.add(empty_label)
        else:
            self.menu = TextMenu(self.config.theme, self.config.show_effects())
            self.menu.set_item_size(self.get_abs_x(0.9115),
                self.get_abs_y(0.07813))

            for playlist in playlists:
                item = TextMenuItem(0.9115, 0.07813, playlist)
                item.set_userdata(playlist)
                self.menu.add_actor(item)

            self.menu.set_position(self.get_abs_x(0.4026),
                self.get_abs_y(0.1823))

            if self.config.show_effects():
                self.menu.set_animate(True)

            self.add(self.menu)

        self.hide_tab()

    def can_activate(self):
        '''Playlists are currently not implemented. This file is a placeholder
        for when the feature is available. Therefore the tab is not active'''
        return False

