"""Base for widgets"""

__licence__ = "GPLv2"
__copyright__ = "2008, Matt Layman"
__author__ = "Matt Layman <laymansterm.dev@gmail.com>"

from entertainerlib.utils.configuration import Configuration

class Base(object):
    """Inherited class that allows for transforms from relative to absolute for
    user interface elements"""

    def __init__(self):
        """Set up by creating config object to get the stage and offset data"""
        self.config = Configuration()

    def get_abs_x(self, percentage):
        """Transform percentage to an abs length based on the stage width"""
        result = int(self.config.get_stage_width() * percentage)
        return result

    def get_abs_y(self, percentage):
        """Transform percentage to an abs length based on the stage height"""
        result = int(self.config.get_stage_height() * percentage)
        return result

    def get_abs_x_pos(self, percentage):
        """Transform percentage to an abs position based on the stage width
        within the restriction of 16:9"""
        result = self.get_abs_x(percentage)
        return result

    def get_abs_y_pos(self, percentage):
        """Transform percentage to an abs position based on the stage height
        within the restriction of 16:9"""
        result = self.get_abs_y(percentage) + self.config.get_vertical_offset()
        return result
