'''Menuitem that contains an image'''

__licence__ = "GPLv2"
__copyright__ = "2007, Lauri Taimila, 2008, Matt Layman"
__author__ = ("Lauri Taimila <lauri@taimila.com>",
              "Matt Layman <laymansterms.dev@gmail.com>")

from entertainerlib.frontend.gui.widgets.menu_item import MenuItem

class ImageMenuItem(MenuItem):
    """
    Simple Image MenuItem

    This menu item contains one Texture that is scaled in such a way that the
    texture fills the whole menu item area. Texture aspect ratio is not
    preserved. ImageMenuItem is defined in terms of its width with a ratio
    determining the height relative to width. This is so the image will scale
    predictably on monitors of different aspect ratios.
    """

    def __init__(self, x_percent, y_to_x_ratio, texture):
        """Initialize menuitem"""

        MenuItem.__init__(self)

        width = self.get_abs_x(x_percent)
        height = self._calculate_height(width, y_to_x_ratio)

        texture.set_size(width, height)

        self.add(texture)

    def _calculate_height(self, width, y_to_x_ratio):
        """Calculate pixel height from the ratio of y to x"""
        height = int(width * y_to_x_ratio)

        return height

