'''Texture that is displayed over video when menu is active'''

__licence__ = "GPLv2"
__copyright__ = "2007, Lauri Taimila"
__author__ = "Lauri Taimila <lauri@taimila.com>"

import clutter

from entertainerlib.frontend.gui.widgets.texture import Texture

class MenuOverlay(Texture):
    """
    Menu overlay widget

    Simple texture that is displayed over video when menu and video are active
    at the same time. Only difference to normal texture is that this texture
    provides methods fade_in() and fade_out().
    """

    #TODO: If user switches quickly from OSD to menu and back, then animation
    #      flickers because the first animation doesn't have time to finish.
    #      This should be fixed! Detect if timeline is still running, stop it
    #      etc.

    def __init__(self, theme):
        """Initialize overlay texture."""
        Texture.__init__(self, filename = theme.getImage("menu_overlay"))
        self.timeline = clutter.Timeline(13, 26)
        self.timeline.set_loop(False)

    def fade_in(self):
        """
        Fade texture in. Animate texture's opacity from 0 to 255
        """
        self.alpha = clutter.Alpha(self.timeline, clutter.smoothstep_dec_func)
        self.behaviour = clutter.BehaviourOpacity(255, 0, self.alpha)
        self.behaviour.apply(self)
        self.timeline.rewind()
        self.timeline.start()

    def fade_out(self):
        """
        Fade texture out. Animate texture's opacity from 255 to 0
        """
        self.alpha = clutter.Alpha(self.timeline, clutter.smoothstep_inc_func)
        self.behaviour = clutter.BehaviourOpacity(255, 0, self.alpha)
        self.behaviour.apply(self)
        self.timeline.rewind()
        self.timeline.start()

