'''Implements basic menu that contains text labels as menuitems'''

__licence__ = "GPLv2"
__copyright__ = "2007, Lauri Taimila"
__author__ = "Lauri Taimila <lauri@taimila.com>"

from entertainerlib.frontend.gui.widgets.selector import Selector
from entertainerlib.frontend.gui.widgets.grid_menu import GridMenu

class TextMenu(GridMenu):
    """
    TextMenu widget

    This widget inherits general GridMenu widget and implements simple textmenu.
    """

    def __init__(self, theme, animate):
        """
        Initialize widget

        @param theme: Theme object
        @param animate: Animate this menu widget (boolean)
        """
        GridMenu.__init__(self)

        self.animate = animate              # Animate this widget behaviour
        self.set_item_size(570, 60)         # Default size for textmenu item

        # Set Cursor
        self.set_cursor_placement(self.BELOW)
        c = Selector(Selector.LARGE, theme)
        c.animate(animate)
        self.set_cursor(c)

    def _update_selected_item(self, new_location, old_location=None):
        """
        Overridden method! See GridMenu API reference.
        @param new_location: Logical location of current menuitem
        @param old_location: Logical location of last menuitem
        """
        if old_location is not None:
            self.items[old_location].set_active(False)
        self.items[new_location].set_active(True)

    def _animate_items_on_state_change(self):
        """
        This method is called when widget is set active or inactive. This
        method allows widget to react this action.
        """
        if len(self.items):
            if self.active:
                self.cursor.show()
                self.items[self.logical_position].set_active(True)
                self.set_opacity(255)
            else:
                self.cursor.hide()
                self.items[self.logical_position].set_active(False)
                self.set_opacity(128)

    def get_index(self, text):
        """
        Returns index of label with the text as passed, returns -1 if not found
        @author Joshua Scotton
        """
        for item in self.items:
            if item.label.get_text() == text:
                return self.items.index(item)
        return -1

