'''Simple menuitem that contains a text self.label (and optionl extras)'''

__licence__ = "GPLv2"
__copyright__ = "2007, Lauri Taimila"
__author__ = "Lauri Taimila <lauri@taimila.com>"

import pango
import clutter

from entertainerlib.frontend.gui.widgets.label import Label
from entertainerlib.frontend.gui.widgets.menu_item import MenuItem

class TextMenuItem(MenuItem):
    """
    Simple menuitem widget that contains text self.label.
    """

    OFFSET = 0.015

    def __init__(self, x_percent, y_percent, label_text, extra_text=None):
        """Initialize menuitem widget."""

        MenuItem.__init__(self)
        self.theme = self.config.theme

        self.active_text_color = self.theme.get_color("menuitem_active")
        self.inactive_text_color = self.theme.get_color("menuitem_inactive")

        self.font_size = 0.47 * y_percent

        self._justified = False

        # Create a rect to ensure that any background selector will span the
        # full length of the item and text won't be scaled and show jaggies
        rect = clutter.Rectangle()
        rect.hide()
        rect.set_size(
            self.get_abs_x(x_percent),
            self.get_abs_y(y_percent))
        self.add(rect)

        # Set self.label text
        try:
            first_line = label_text[:label_text.index('\n')]
        except ValueError:
            first_line = label_text
        self.label = Label(self.font_size, "menuitem_inactive", 0, 0,
            first_line, "text_label")
        self.label.set_ellipsize(pango.ELLIPSIZE_END)
        self.label.position = (self.OFFSET,
            (y_percent - self.label.height) / 2)
        self.add(self.label)

        # Set extra text
        if extra_text is not None:
            extra = Label(self.font_size, "menuitem_inactive", 0, 0,
                extra_text, "text_label")
            extra.position = (x_percent - extra.width - self.OFFSET,
                (y_percent - self.label.height) / 2)
            self.add(extra)

            self.label.width = x_percent - extra.width - (self.OFFSET * 2.5)
        else:
            self.label.width = x_percent - (self.OFFSET * 2)

    def set_active(self, boolean):
        """
        Set menuitem active or inactive. Changes the text color of the
        menuitem.

        @param boolean: use True to set active and False to set inactive
        """
        MenuItem.set_active(self, boolean)
        if boolean:
            for index in range(self.get_n_children()):
                actor = self.get_nth_child(index)
                if actor.get_name() == "text_label":
                    actor.set_color(self.active_text_color)
                    if self._justified:
                        actor.font_size = self.font_size * 1.35
        else:
            for index in range(self.get_n_children()):
                actor = self.get_nth_child(index)
                if actor.get_name() == "text_label":
                    actor.set_color(self.inactive_text_color)
                    if self._justified:
                        actor.font_size = self.font_size

    def _get_justified(self):
        """Return the justified property"""
        return self._justified

    def _set_justified(self, justified):
        """Set the justified property"""
        self._justified = justified

    justified = property(_get_justified, _set_justified)

