'''Test mock objects'''
# pylint: disable-msg=W0231

from entertainerlib.frontend.backend_connection import BackendConnection
from entertainerlib.frontend.media_player import MediaPlayer
from entertainerlib.frontend.medialibrary.feeds import Entry
from entertainerlib.frontend.medialibrary.feeds import Feed
from entertainerlib.frontend.medialibrary.feeds import FeedLibrary
from entertainerlib.frontend.medialibrary.images import Image
from entertainerlib.frontend.medialibrary.images import ImageLibrary
from entertainerlib.frontend.medialibrary.music import Album
from entertainerlib.frontend.medialibrary.music import MusicLibrary
from entertainerlib.frontend.medialibrary.music import Track
from entertainerlib.frontend.medialibrary.videos import Movie
from entertainerlib.frontend.medialibrary.videos import TVEpisode
from entertainerlib.frontend.medialibrary.videos import TVSeries
from entertainerlib.frontend.medialibrary.videos import VideoLibrary

class MockAlbum(Album):
    '''Mock entertainerlib.frontend.medialibrary.music.Album'''

    def __init__(self, title=None, cursor=None, make_track=True):
        self.title = 'Ganging Up on the Sun'
        self.total_length = 120
        if make_track:
            self.mock_track = MockTrack(make_album=False)

    def get_number_of_tracks(self):
        '''See `Album.get_number_of_tracks`.'''
        return 1

    def get_tracks(self):
        '''See `Album.get_tracks`.'''
        return [self.mock_track]

    def get_year(self):
        '''See `Album.get_year`.'''
        return '2009'

    def has_album_art(self):
        '''See `Album.has_album_art`.'''
        return False


class MockBackendConnection(BackendConnection):
    '''Mock entertainerlib.frontend.backend_connection.BackendConnection'''

    def __init__(self):
        '''Override init to prevent BackenConnection from attempting to connect
        to a message bus.'''

    def close_connection(self):
        '''See `BackendConnection.close_connection`.'''


class MockClutterKeyboardEvent(object):
    '''Mock clutter keyboard events'''

    def __init__(self, key_value):
        # Must match binding property name
        self._keyval = key_value

    @property
    def keyval(self):
        '''Simulate the key value stored in a clutter keyboard event.'''
        return self._keyval


class MockEntry(Entry):
    '''Mock entertainerlib.frontend.medialibrary.feeds.Entry'''

    def __init__(self, title=None, description=None, identifier=None,
        time=None, date=None, read=False):
        self.date = 'January 31st'
        self.description = "What!? I have to describe this thing?"
        self.time = 'Too early'
        self.title = 'Fake Entry'

    def mark_as_read(self):
        '''Override to do nothing. See `Entry.mark_as_read` for more info.'''


class MockFeed(Feed):
    '''Mock entertainerlib.frontend.medialibrary.feeds.Feed'''

    def __init__(self, url=None):
        self.date = 'January 31st'
        self.subtitle = 'Whoa, a subtitle.'
        self.time = 'Too early'
        self.title = 'Fake Feed'

    def get_entries(self):
        '''See `Feed.has_media`.'''
        return []


class MockFeedLibrary(FeedLibrary):
    '''Mock entertainerlib.frontend.medialibrary.feeds.FeedLibrary'''

    def __init__(self, backend_connection=None):
        '''Override the intial behavior.'''

    def is_empty(self):
        '''See `FeedLibrary.is_empty`.'''
        return True


class MockImage(Image):
    '''Mock entertainerlib.frontend.medialibrary.images.Image'''

    def __init__(self, filename=None, album_path=None, title=None,
        description=None, date=None, time=None, width=None, height=None,
        filesize=None, thumb_hash=None):
        self._Image__description = 'What a terrible image'
        self._Image__filename = filename
        self._Image__title = 'A title'


class MockImageLibrary(ImageLibrary):
    '''Mock entertainerlib.frontend.medialibrary.images.ImageLibrary'''

    def __init__(self, backend_connection=None):
        '''Override the intial behavior.'''

    def get_number_of_albums(self):
        '''See `ImageLibrary.get_number_of_albums`.'''
        return 0


class MockMediaPlayer(MediaPlayer):
    '''Mock entertainerlib.frontend.media_player.MediaPlayer'''

    def __init__(self, stage=None, width=None, height=None):
        '''Override any actual media player set up.'''

    def has_media(self):
        '''See `MediaPlayer.has_media`.'''
        return False

    def is_playing(self):
        '''See `MediaPlayer.is_playing`.'''
        return False

    def play(self):
        '''See `MediaPlayer.play`.'''

    def set_media(self, playable=None, internal_call=False):
        '''See `MediaPlayer.set_media`.'''


class MockMovie(Movie):
    '''Mock entertainerlib.frontend.medialibrary.videos.Movie'''

    def __init__(self, filename=None):
        '''Override init to prevent a database connection'''

    def get_actors(self):
        '''See `Movie.get_actors`.'''
        return ['Tim Robbins']

    def get_directors(self):
        '''See `Movie.get_directors`.'''
        return ['Frank Darabont']

    def get_genres(self):
        '''See `Movie.get_genres`.'''
        return ['Drama']

    def get_plot(self):
        '''See `Movie.get_plot`.'''
        return 'An innocent man is sent to prison'

    def get_rating(self):
        '''See `Movie.get_rating`.'''
        return 5

    def get_runtime(self):
        '''See `Movie.get_runtime`.'''
        return ""

    def get_title(self):
        '''See `Movie.get_title`.'''
        return 'The Shawshank Redemption'

    def get_writers(self):
        '''See `Movie.get_writers`.'''
        return ['Frank Darabont']

    def get_year(self):
        '''See `Movie.get_year`.'''
        return 1994

    def has_cover_art(self):
        '''See `Movie.has_cover_art`.'''
        return False

class MockMusicLibrary(MusicLibrary):
    '''Mock entertainerlib.frontend.medialibrary.music.MusicLibrary'''

    def __init__(self, backend_connection=None):
        '''Override the intial behavior.'''

    def get_albums_by_artist(self, artist=None):
        '''See `MusicLibrary.get_albums_by_artist`.'''
        return []

    def get_compact_disc_information(self):
        '''See `MusicLibrary.get_compact_disc_information`.
        Raise an exception to simulate no disc.'''
        raise Exception('No disc in drive')

    def get_tracks_by_artist(self, artist=None):
        '''See `MusicLibrary.get_tracks_by_artist`.'''
        return []

    def number_of_tracks(self):
        '''See `MusicLibrary.number_of_tracks`.'''
        return 0

    def __del__(self):
        '''See `MusicLibrary.__del__`.'''


class MockTVEpisode(TVEpisode):
    '''Mock entertainerlib.frontend.medialibrary.videos.TVEpisode'''

    def __init__(self, title=None):
        '''Override init to prevent a database connection'''

    def get_episode_number(self):
        '''See `TVEpisode.get_episode_number`.'''
        return 1

    def get_plot(self):
        '''See `TVEpisode.get_plot`.'''
        return 'Dr. House continues to be a jerk'

    def get_thumbnail_url(self):
        '''See `TVEpisode.get_thumbnail_url`.'''
        return None

    def get_title(self):
        '''See `TVEpisode.get_title`.'''
        return 'Something clever'


class MockTVSeries(TVSeries):
    '''Mock entertainerlib.frontend.medialibrary.videos.TVSeries'''

    def __init__(self, title=None):
        '''Override init to prevent a database connection'''

    def get_episodes_from_season(self, season_number=1):
        '''See `TVSeries.get_episodes_from_season`.'''
        mock_episode = MockTVEpisode()
        return [mock_episode]

    def get_seasons(self):
        '''See `TVSeries.get_seasons`.'''
        return []

    def get_title(self):
        '''See `TVSeries.get_title`.'''
        return 'House'

    def has_cover_art(self):
        '''See `TVSeries.has_cover_art`.'''
        return False

class MockTrack(Track):
    '''Mock entertainerlib.frontend.medialibrary.music.Track'''

    def __init__(self, filename=None, title=None, tracknumber=None, artist=None,
        album=None, genre=None, bitrate=None, year=None, rating=None,
        length=None, comment=None, lyrics=None, make_album=True):
        self.artist = 'Guster'
        self.length = 60
        self.lyrics = 'Here are some lyrics'
        self.title = 'One Man Wrecking Machine'
        self.tracknumber = 0
        if make_album:
            self.album = MockAlbum(make_track=False)

    def get_album(self, cursor=False):
        '''See `Track.get_album`.'''
        return self.album


class MockVideoLibrary(VideoLibrary):
    '''Mock entertainerlib.frontend.medialibrary.videos.VideoLibrary'''

    def __init__(self, backend_connection=None):
        '''Override the intial behavior.'''

    def get_number_of_movies(self):
        '''See `VideoLibrary.get_number_of_movies`.'''
        return 0

    def get_number_of_tv_series(self):
        '''See `VideoLibrary.get_number_of_tv_series`.'''
        return 0

    def get_number_of_video_clips(self):
        '''See `VideoLibrary.get_number_of_video_clips`.'''
        return 0

