"""Tests Base"""

__license__ = "GPLv2"
__copyright__ = "2008, Matt Layman"
__author__ = "Matt Layman <laymansterms.dev@gmail.com>"

from entertainerlib.frontend.gui.widgets.base import Base
from entertainerlib.tests import EntertainerTest

class BaseTest(EntertainerTest):
    """Test for entertainerlib.frontend.gui.widgets.base"""

    def setUp(self):
        """Set up the test"""
        EntertainerTest.setUp(self)

        self.base = Base()

    def tearDown(self):
        """Clean up after the test"""
        EntertainerTest.tearDown(self)

    def testCreate(self):
        """Test Base object creation"""
        self.assertTrue(isinstance(self.base, Base))

    def testGetAbsX(self):
        """Test getting the absolute size of x based on the stage width"""
        self.assertEqual(self.base.get_abs_x(.25), 341)

    def testGetAbsY(self):
        """Test getting the absolute size of y based on the stage height"""
        self.assertEqual(self.base.get_abs_y(.25), 192)

    def testGetAbsXPos(self):
        """Test getting the position of x within the 16:9 viewing area"""
        self.assertEqual(self.base.get_abs_x_pos(.25), 341)

    def testGetAbsYPos(self):
        """Test getting the position of y within the 16:9 viewing area"""
        # Need to modify the private config for this test to get an interesting
        # stage size that actually has an offset
        self.base.config.set_stage_width(16)
        self.base.config.set_stage_height(11)

        self.assertEqual(self.base.get_abs_y_pos(.5), 6)

