'''Test FeedConfigTools'''

__licence__ = "GPLv2"
__copyright__ = "2008, Joshua Scotton"
__author__ = "Joshua Scotton <josh@joshuascotton.com>"

import os

import gtk
import gtk.glade

from entertainerlib.utils.feed_utils import FeedConfigTools
from entertainerlib.tests import EntertainerTest

THIS_DIR = os.path.dirname(__file__)


class FeedConfigToolsTest(EntertainerTest):
    '''Test for entertainerlib.utils.feed_utils FeedConfigTools'''

    def setUp(self):
        """Sets up everything for the test"""
        EntertainerTest.setUp(self)

        #setup feeds and model
        self.feeds = self.config.get_feeds()
        self.model = gtk.ListStore(str)
        for i in range(len(self.feeds)):
            self.model.insert(i, [self.feeds[i]])

        self.files = [THIS_DIR + "/data/FeedConfigTools/test.opml"]

        self.feedList = [
            u'http://www.hackaday.com/rss.xml',
            u'http://edevelop.org/planet/rss20.xml',
            u'http://feeds.feedburner.com/BlenderartMagazine'
            ]

        self.result_feed_list = self.feeds + self.feedList

        self.feed_config_tools = FeedConfigTools()

    def tearDown(self):
        """restores config to how it should be to start off"""
        EntertainerTest.tearDown(self)

    def testAddFileFeedsToWidget001(self):
        """Tests if self.feeds is updated correctly"""
        self.feed_config_tools.add_file_feeds_to_widget(
            self.files, self.model, self.feeds, False)
        self.assertEqual(self.feeds, self.result_feed_list)

    def testAddFileFeedsToWidget002(self):
        """Tests if self.config is updated correctly"""
        self.feed_config_tools.add_file_feeds_to_widget(
            self.files, self.model, self.feeds, False)
        self.assertEqual(self.config.get_feeds(), self.result_feed_list)

    def testAddFeedsToWidget001(self):
        """Tests if self.feeds is updated correctly"""
        self.feed_config_tools.add_feeds_to_widget(
            self.feedList, self.model, self.feeds)
        self.assertEqual(self.feeds, self.result_feed_list)

    def testAddFeedsToWidget002(self):
        """Tests if self.config is updated correctly"""
        self.feed_config_tools.add_feeds_to_widget(
            self.feedList, self.model, self.feeds)
        self.assertEqual(self.config.get_feeds(), self.result_feed_list)

