'''Test feed entry parser'''
# pylint: disable-msg=C0301

__licence__ = "GPLv2"
__copyright__ = "2008, Joshua Scotton"
__author__ = "Joshua Scotton <josh@joshuascotton.com>"

import unittest

from entertainerlib.utils.feed_utils import FeedEntryParser


class FeedEntryParserTest(unittest.TestCase):
    '''Test the FeedEntryParser'''

    def setUp(self):
        """Sets up everything for the test"""

        #test strings
        self.testString001 = "<body><b>Hello World</body></b>"
        self.testString002 = "<body><span id=\"001\"><u><b>&nbsp;He<i>l</i>lo <big>World</b></big><s>!</s><sub>!</sub><div><sup>!</sup><small>!</small><tt></div>...</tt></u></span></body>"
        self.resultString001 = "Hello World"
        self.resultString002 = "<span id=\"001\"><u><b>&nbsp;He<i>l</i>lo <big>World</b></big><s>!</s><sub>!</sub><sup>!</sup><small>!</small><tt>...</tt></u></span>"
        self.resultString003 = "<body>Hello World</body>"
        self.resultString004 = "<span id=\"001\"><u><b> He<i>l</i>lo <big>World</b></big><s>!</s><sub>!</sub><sup>!</sup><small>!</small><tt>...</tt></u></span>"

    def testStripTags001(self):
        """tests if FeedEntryParser strips all tags from input using default
        tags
        """
        output = FeedEntryParser().strip_tags(self.testString001)
        self.assertEqual(output, self.resultString001)

    def testStripTags002(self):
        """tests if FeedEntryParser strips all tags from input using
        non-default tags
        """
        output = FeedEntryParser().strip_tags(self.testString001, ["body"])
        self.assertEqual(output, self.resultString003)

    def testStripNonPangoTags(self):
        """testStripNonPangoTags: tests if FeedEntryParser strips all
        non-pango tags from input
        """
        output = FeedEntryParser().strip_non_pango_tags(self.testString002)
        self.assertEqual(output, self.resultString002)

    def testConvert(self):
        """tests if FeedEntryParser converts input to correct output"""
        output = FeedEntryParser().convert(self.testString002)
        self.assertEqual(output, self.resultString004)

