"""Tests ImageMenuItem"""
# pylint: disable-msg=W0212

__license__ = "GPLv2"
__copyright__ = "2008, Matt Layman"
__author__ = "Matt Layman <laymansterms.dev@gmail.com>"

import os

from entertainerlib.frontend.gui.widgets.image_menu_item import ImageMenuItem
from entertainerlib.frontend.gui.widgets.texture import Texture
from entertainerlib.tests import EntertainerTest

THIS_DIR = os.path.dirname(__file__)

class ImageMenuItemTest(EntertainerTest):
    """Test for entertainerlib.frontend.gui.widgets.image_menu_item"""

    def setUp(self):
        """Set up the test"""
        EntertainerTest.setUp(self)

        self.filename = os.path.join(THIS_DIR, 'data/ImageThumbnailer/test.jpg')
        self.texture = Texture(self.filename)
        self.y_to_x_ratio = 1

        self.image = ImageMenuItem(.1, self.y_to_x_ratio, self.texture)

    def tearDown(self):
        """Clean up after the test"""
        EntertainerTest.tearDown(self)

    def testCreate(self):
        """Test correct ImageMenuItem initialization"""
        self.assertTrue(isinstance(self.image, ImageMenuItem))

    def testWidth(self):
        """Test correct width setting"""
        self.assertEqual(self.texture.get_width(), 136)

    def testHeight(self):
        """Test correct height setting"""
        width = self.texture.get_width()
        self.assertEqual(self.image._calculate_height(width, self.y_to_x_ratio),
            136)
        self.assertEqual(self.texture.get_height(), 136)

    def testRatio(self):
        """Test that ratio correctly calculates the expected heights"""
        texture2 = Texture(self.filename)
        ImageMenuItem(.1, .5, texture2)
        self.assertEqual(texture2.get_height(), 68)

        texture3 = Texture(self.filename)
        ImageMenuItem(.1, 2, texture3)
        self.assertEqual(texture3.get_height(), 272)

