"""Tests Label"""
# pylint: disable-msg=W0212

__license__ = "GPLv2"
__copyright__ = "2008, Matt Layman"
__author__ = "Matt Layman <laymansterms.dev@gmail.com>"

import clutter

from entertainerlib.frontend.gui.widgets.base import Base
from entertainerlib.frontend.gui.widgets.label import Label
from entertainerlib.tests import EntertainerTest

class LabelTest(EntertainerTest):
    """Test for entertainerlib.frontend.gui.widgets.label"""

    def setUp(self):
        """Set up the test"""
        EntertainerTest.setUp(self)

        self.label = Label(0.1, "screentitle", 0.1, 0.2, "Test Label text",
            "test_name")

    def tearDown(self):
        """Clean up after the test"""
        EntertainerTest.tearDown(self)

    def testCreate(self):
        """Test correct Label initialization"""
        self.assertTrue(isinstance(self.label, (Base, clutter.Label)))

    def testSetSize(self):
        """Test correct size setting"""
        self.label.set_size(.75, .8)
        self.assertEqual(self.label.get_size(), (1024, 614))
        self.assertEqual(self.label.width, 0.75)

    def testInitWidth(self):
        """Test that the initial width has a value if the width property has
        not been set"""
        self.assertAlmostEqual(self.label.width, 0.357247437)

    def testWidth(self):
        """Test the width property"""
        self.label.width = 0.5
        self.assertEqual(self.label.width, 0.5)

        self.label._set_width(0.4)
        self.assertEqual(self.label._get_width(), 0.4)

    def testFontSize(self):
        """Test the font size property"""
        self.label.font_size = 0.2
        self.assertEqual(self.label.font_size, 0.2)

        self.label._set_font_size(0.3)
        self.assertEqual(self.label._get_font_size(), 0.3)

    def testInitHeight(self):
        """Test that the initial height has a value if the height property has
        not been set"""
        self.assertAlmostEqual(self.label.height, 0.11197916)

    def testHeight(self):
        """Test the height property"""
        self.label.height = 0.5
        self.assertEqual(self.label.height, 0.5)

        self.label._set_height(0.4)
        self.assertEqual(self.label._get_height(), 0.4)

    def testPosition(self):
        """Test the position property"""
        self.assertEqual(self.label.position, (0.1, 0.2))

        self.label.position = (0.4, 0.5)
        self.assertEqual(self.label.position, (0.4, 0.5))

        self.label._set_position((0.3, 0.6))
        self.assertEqual(self.label._get_position(), (0.3, 0.6))

