'''Tests Weather'''

__licence__ = "GPLv2"
__copyright__ = "2008, Jamie Bennett"
__author__ = "Jamie Bennett <jamie@linuxuk.org>"

from datetime import datetime

from entertainerlib.tests import EntertainerTest
from entertainerlib.utils.weather import Weather

class WeatherTest(EntertainerTest):
    """
    WeatherTest class
    Tests for the weather module.
    @author: Jamie Bennett <jamie@linuxuk.org>
    """
    def setUp(self):
        """Sets up everything for the test"""
        EntertainerTest.setUp(self)

        self.weather = Weather("Bath,England")

    def tearDown(self):
        """Clean up after the test"""
        EntertainerTest.tearDown(self)

    def testWeatherFindRemote(self):
        """Tests the weather code using a call to the outside world"""
        self.weather.set_location('Bath,England')
        self.weather.refresh()
        forecasts = self.weather.get_forecasts()
        today = forecasts[0]
        day = datetime.now().strftime('%a')
        self.assertEqual(str(today["Day"]), day)

    def testWeatherSet(self):
        """Tests the setting of a forecast to a given state"""
        self.weather.clear_forecasts()
        forecast = {"Day":"Today", "Low":18, "High":20, "Condition":"Sunny"}
        self.weather.add_forecast(forecast)
        forecasts = self.weather.get_forecasts()
        today = forecasts[0]
        self.assertEqual(today["Day"],"Today")
        self.assertEqual(today["Low"], 18)
        self.assertEqual(today["High"], 20)
        self.assertEqual(today["Condition"],"Sunny")

    def testWeatherSetLocation(self):
        """Tests the location setting of the weather module"""
        self.weather.set_location('Bradford,England')
        self.assertEqual(self.weather.get_location(), 'Bradford,England')

    def testWeatherLocationLatinEncoding(self):
        """Tests whether code can handle Latin-1 encoding back from google"""
        #Check for Montreal which gets info back from google in Latin-1
        self.weather.set_location("Montreal")
        self.weather.refresh()
        results = self.weather.get_forecasts()
        #if there are results then it's working
        self.assertTrue(len(results) > 0)
